from jd.api.rest.ComEpiPromoOpenApiWriteCreateSuitPromoRequest import ComEpiPromoOpenApiWriteCreateSuitPromoRequest
from jd.api.rest.ComJdStockShopGlobalWebOpenWarehouseFacadeAddStoreRequest import ComJdStockShopGlobalWebOpenWarehouseFacadeAddStoreRequest
from jd.api.rest.ComJdThPopOpenOrderDeliveryFacadeSplitOrderRequest import ComJdThPopOpenOrderDeliveryFacadeSplitOrderRequest
from jd.api.rest.ComJdThPopOpenOrderInformationFacadeQueryPaymentDetailInfoRequest import ComJdThPopOpenOrderInformationFacadeQueryPaymentDetailInfoRequest
from jd.api.rest.ComJdOverseaApiProductUpdateApiServiceRequest import ComJdOverseaApiProductUpdateApiServiceRequest
from jd.api.rest.ComJdSellerOrderApiDeliveryFacadeDeliveryRequest import ComJdSellerOrderApiDeliveryFacadeDeliveryRequest
from jd.api.rest.ComJdJinVenderHandlerOpenStatementFacadeStatementDetailRequest import ComJdJinVenderHandlerOpenStatementFacadeStatementDetailRequest
from jd.api.rest.ComJdOverseaApiProductUpdateApiServiceDeleteSkuRequest import ComJdOverseaApiProductUpdateApiServiceDeleteSkuRequest
from jd.api.rest.ComProductUpdateApiServiceUpdateSpuRequest import ComProductUpdateApiServiceUpdateSpuRequest
from jd.api.rest.VenderGetVenderCategoryByVenderIdI18NRequest import VenderGetVenderCategoryByVenderIdI18NRequest
from jd.api.rest.VenderSellerWebControllerOpenCompanyVenderCompanyFacadeGetCompanyByVenderIdRequest import VenderSellerWebControllerOpenCompanyVenderCompanyFacadeGetCompanyByVenderIdRequest
from jd.api.rest.ComJdThPopOpenOrderInformationFacadeListOrderRequest import ComJdThPopOpenOrderInformationFacadeListOrderRequest
from jd.api.rest.ComJdSellerOrderApiDeliveryFacadeSplitRequest import ComJdSellerOrderApiDeliveryFacadeSplitRequest
from jd.api.rest.ComProductUpdateApiServiceUpdateSkusRequest import ComProductUpdateApiServiceUpdateSkusRequest
from jd.api.rest.ThSellerPopUpdateStoreSkuPriceRequest import ThSellerPopUpdateStoreSkuPriceRequest
from jd.api.rest.ThSellerPopUpdateStoreSkuStockRequest import ThSellerPopUpdateStoreSkuStockRequest
from jd.api.rest.ComJdThPopOpenOrderPrintFacadePrintLabelRequest import ComJdThPopOpenOrderPrintFacadePrintLabelRequest
from jd.api.rest.ComJdSellerOrderApiPrintFacadePrintRequest import ComJdSellerOrderApiPrintFacadePrintRequest
from jd.api.rest.ComEpiCouponOpenApiReadCouponDetailRequest import ComEpiCouponOpenApiReadCouponDetailRequest
from jd.api.rest.ComProductUpdateApiServiceSaveProductRequest import ComProductUpdateApiServiceSaveProductRequest
from jd.api.rest.VenderGetVenderShopCategoryByVenderIdI18NRequest import VenderGetVenderShopCategoryByVenderIdI18NRequest
from jd.api.rest.ComProductQueryApiServiceQuerycategoryRequest import ComProductQueryApiServiceQuerycategoryRequest
from jd.api.rest.ComJdSellerOrderApiOperationFacadeAcceptOrderRequest import ComJdSellerOrderApiOperationFacadeAcceptOrderRequest
from jd.api.rest.ComJdIntlAsmShopAfsApiServiceQueryDetailRequest import ComJdIntlAsmShopAfsApiServiceQueryDetailRequest
from jd.api.rest.ComJdwlApiOrderTrackSiteJsfExportOrderTrackSiteExportAddIntlOrderTrackRequest import ComJdwlApiOrderTrackSiteJsfExportOrderTrackSiteExportAddIntlOrderTrackRequest
from jd.api.rest.ComJdSellerOrderApiOperationFacadeRecallOrderRequest import ComJdSellerOrderApiOperationFacadeRecallOrderRequest
from jd.api.rest.ComProductQueryApiServiceQueryskusRequest import ComProductQueryApiServiceQueryskusRequest
from jd.api.rest.ComJdSellerOrderApiOperationFacadeVerifyOrderRequest import ComJdSellerOrderApiOperationFacadeVerifyOrderRequest
from jd.api.rest.ComEpiPromoOpenApiWriteCreateSumPromoRequest import ComEpiPromoOpenApiWriteCreateSumPromoRequest
from jd.api.rest.ComEpiCouponOpenApiReadCouponListRequest import ComEpiCouponOpenApiReadCouponListRequest
from jd.api.rest.ComProductQueryApiServiceQueryProductByIdRequest import ComProductQueryApiServiceQueryProductByIdRequest
from jd.api.rest.JosVoucherInfoGetRequest import JosVoucherInfoGetRequest
from jd.api.rest.ComJdwlSellerAlphaOpenServiceGetDeliveryRecommendCarriersForOpenRequest import ComJdwlSellerAlphaOpenServiceGetDeliveryRecommendCarriersForOpenRequest
from jd.api.rest.ComEpiPromoOpenApiWriteDelPromoRequest import ComEpiPromoOpenApiWriteDelPromoRequest
from jd.api.rest.CommonImageUploadFileRequest import CommonImageUploadFileRequest
from jd.api.rest.ComJdThPopOpenOrderPrintFacadeGetOrderShippingListRequest import ComJdThPopOpenOrderPrintFacadeGetOrderShippingListRequest
from jd.api.rest.ComEpiPromoOpenApiReadGetUnitPromoRequest import ComEpiPromoOpenApiReadGetUnitPromoRequest
from jd.api.rest.PopAdminExportQueryListNewRequest import PopAdminExportQueryListNewRequest
from jd.api.rest.ComJdPopVenderCenterI18nApiVenderVenderBasicFacadeGetVenderInfoByVenderIdRequest import ComJdPopVenderCenterI18nApiVenderVenderBasicFacadeGetVenderInfoByVenderIdRequest
from jd.api.rest.ComJdIntlAsmShopAfsApiServiceQueryAllRequest import ComJdIntlAsmShopAfsApiServiceQueryAllRequest
from jd.api.rest.JosMasterKeyGetRequest import JosMasterKeyGetRequest
from jd.api.rest.ComJdThPopOpenOrderInformationFacadeQueryOrderDetailRequest import ComJdThPopOpenOrderInformationFacadeQueryOrderDetailRequest
from jd.api.rest.I18nPlaceOrderServiceJsfGetPreWaybillCodeForOpenApiRequest import I18nPlaceOrderServiceJsfGetPreWaybillCodeForOpenApiRequest
from jd.api.rest.ComJdJinVenderHandlerOpenStatementFacadeListStatementRequest import ComJdJinVenderHandlerOpenStatementFacadeListStatementRequest
from jd.api.rest.ComJdAddressInternationalGlscGlscAddressCodingServiceWSGetChildrenRequest import ComJdAddressInternationalGlscGlscAddressCodingServiceWSGetChildrenRequest
from jd.api.rest.ComJdAddressInternationalGlscGlscAddressCodingServiceWSParseAddressCodingRequest import ComJdAddressInternationalGlscGlscAddressCodingServiceWSParseAddressCodingRequest
from jd.api.rest.JosSecretApiReportGetRequest import JosSecretApiReportGetRequest
from jd.api.rest.ComProductQueryApiServiceQuerySkusByOuterIdsRequest import ComProductQueryApiServiceQuerySkusByOuterIdsRequest
from jd.api.rest.ComJdAdwordApiServiceAdwordSellerApiServiceCreateAdwordForSkuRequest import ComJdAdwordApiServiceAdwordSellerApiServiceCreateAdwordForSkuRequest
from jd.api.rest.ComJdAdwordApiServiceAdwordSellerApiServiceQueryAdwordsBySkuIdRequest import ComJdAdwordApiServiceAdwordSellerApiServiceQueryAdwordsBySkuIdRequest
from jd.api.rest.ComEpiPromoOpenApiReadGetPromoMainSkuRequest import ComEpiPromoOpenApiReadGetPromoMainSkuRequest
from jd.api.rest.ComJdAdwordApiServiceAdwordSellerApiServiceDeleteAdwordsBySkuIdRequest import ComJdAdwordApiServiceAdwordSellerApiServiceDeleteAdwordsBySkuIdRequest
from jd.api.rest.ComEpiBranchOpenApiReadBranchListRequest import ComEpiBranchOpenApiReadBranchListRequest
from jd.api.rest.StockUpdateSkuStockRequest import StockUpdateSkuStockRequest
from jd.api.rest.ComJdPopVenderCenterI18nApiBusinessBusinessCheckFacadeRequest import ComJdPopVenderCenterI18nApiBusinessBusinessCheckFacadeRequest
from jd.api.rest.ComJdSellerOrderApiInformationFacadeGetPromotionDetailRequest import ComJdSellerOrderApiInformationFacadeGetPromotionDetailRequest
from jd.api.rest.ComEpiBranchOpenApiReadBranchDetailRequest import ComEpiBranchOpenApiReadBranchDetailRequest
from jd.api.rest.ComEpiBranchOpenApiWriteBranchCreationRequest import ComEpiBranchOpenApiWriteBranchCreationRequest
from jd.api.rest.JingdongComEpiBranchOpenApiWriteBranchModifyRequest import JingdongComEpiBranchOpenApiWriteBranchModifyRequest
from jd.api.rest.StockAddWareStockRequest import StockAddWareStockRequest
from jd.api.rest.ComEpiBranchOpenApiWriteUpdateStatusRequest import ComEpiBranchOpenApiWriteUpdateStatusRequest
from jd.api.rest.ComJdSellerTrackApiTrackSynFacadeRequest import ComJdSellerTrackApiTrackSynFacadeRequest
from jd.api.rest.StockGetStoreListRequest import StockGetStoreListRequest
from jd.api.rest.ComEpiPromoOpenApiReadGetGiftPromoRequest import ComEpiPromoOpenApiReadGetGiftPromoRequest
from jd.api.rest.PromotionPriceUpdateSkuPriceJsonWithVenderIdRequest import PromotionPriceUpdateSkuPriceJsonWithVenderIdRequest
from jd.api.rest.StockBatchQueryStockRequest import StockBatchQueryStockRequest
from jd.api.rest.ComEpiPromoOpenApiReadGetSuitPromoRequest import ComEpiPromoOpenApiReadGetSuitPromoRequest
from jd.api.rest.ComEpiPromoOpenApiReadGetPromoListForPageRequest import ComEpiPromoOpenApiReadGetPromoListForPageRequest
from jd.api.rest.ComJdPopVenderCenterI18nApiShopVenderShopFacadeGetVenderShopByVenderIdRequest import ComJdPopVenderCenterI18nApiShopVenderShopFacadeGetVenderShopByVenderIdRequest
from jd.api.rest.VenderSellerWebControllerOpenVenderAddrVenderAddrFacadeListVenderTakeAddressRequest import VenderSellerWebControllerOpenVenderAddrVenderAddrFacadeListVenderTakeAddressRequest
from jd.api.rest.VenderSellerWebControllerOpenVenderAddrVenderAddrFacadeListVenderReturnAddressRequest import VenderSellerWebControllerOpenVenderAddrVenderAddrFacadeListVenderReturnAddressRequest
from jd.api.rest.ComJdGmsGreatdaneCategoryServiceReadCategoryReadServiceGetCategorysRequest import ComJdGmsGreatdaneCategoryServiceReadCategoryReadServiceGetCategorysRequest
from jd.api.rest.ComJdJinVenderHandlerOpenStatementFacadeConfirmStatementRequest import ComJdJinVenderHandlerOpenStatementFacadeConfirmStatementRequest
from jd.api.rest.PopAdminExportOrderDeliveryNewRequest import PopAdminExportOrderDeliveryNewRequest
from jd.api.rest.ComJdJinVenderHandlerOpenStatementFacadeOrderSettlementListRequest import ComJdJinVenderHandlerOpenStatementFacadeOrderSettlementListRequest
from jd.api.rest.ComJdSellerOrderApiInformationFacadeGetOrderListRequest import ComJdSellerOrderApiInformationFacadeGetOrderListRequest
from jd.api.rest.ComJdSellerOrderApiInformationFacadeGetOrderDetailRequest import ComJdSellerOrderApiInformationFacadeGetOrderDetailRequest
from jd.api.rest.ComEpiPromoOpenApiWriteResumePromoRequest import ComEpiPromoOpenApiWriteResumePromoRequest
from jd.api.rest.ComProductUpdateApiServiceChangeSkuStatusRequest import ComProductUpdateApiServiceChangeSkuStatusRequest
from jd.api.rest.ComEpiPromoOpenApiWriteSuspendPromoRequest import ComEpiPromoOpenApiWriteSuspendPromoRequest
from jd.api.rest.ComProductQueryApiServiceQueryProductsRequest import ComProductQueryApiServiceQueryProductsRequest
from jd.api.rest.ComProductUpdateApiServiceChangeProductStatusRequest import ComProductUpdateApiServiceChangeProductStatusRequest
from jd.api.rest.ComJdEtmsWaybillApiGlscGlscWaybillTraceApiGetTraceInfoByOrderRequest import ComJdEtmsWaybillApiGlscGlscWaybillTraceApiGetTraceInfoByOrderRequest
from jd.api.rest.VenderGetVenderBrandByVenderIdForI18NRequest import VenderGetVenderBrandByVenderIdForI18NRequest
from jd.api.rest.ComJdThPopOpenOrderCancelFacadeSubmitCancelOrderRequest import ComJdThPopOpenOrderCancelFacadeSubmitCancelOrderRequest
from jd.api.rest.ComJdSellerOrderApiCancelFacadeSubmitRequest import ComJdSellerOrderApiCancelFacadeSubmitRequest
from jd.api.rest.ComEpiCouponOpenApiWriteCloseCouponRequest import ComEpiCouponOpenApiWriteCloseCouponRequest
from jd.api.rest.ComJdSellerOrderApiCancelFacadeReviewRequest import ComJdSellerOrderApiCancelFacadeReviewRequest
from jd.api.rest.ComEpiCouponOpenApiWriteCreateCouponRequest import ComEpiCouponOpenApiWriteCreateCouponRequest
from jd.api.rest.ThSellerPopSearchStoreSkuListRequest import ThSellerPopSearchStoreSkuListRequest
from jd.api.rest.ThSellerPopSkuBindStoreRequest import ThSellerPopSkuBindStoreRequest
from jd.api.rest.ComEpiPromoOpenApiReadGetTotalPricePromoRequest import ComEpiPromoOpenApiReadGetTotalPricePromoRequest
from jd.api.rest.ThSellerPopUpdateStoreSkuStatusRequest import ThSellerPopUpdateStoreSkuStatusRequest
from jd.api.rest.ComEpiPromoOpenApiWriteCreateUnitPromoRequest import ComEpiPromoOpenApiWriteCreateUnitPromoRequest
from jd.api.rest.ComEpiPromoOpenApiWriteCreateGiftPromoRequest import ComEpiPromoOpenApiWriteCreateGiftPromoRequest



from jd.api.base import RestApi

class ComJdAdwordApiServiceAdwordSellerApiServiceCreateAdwordForSkuRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.pcLink = None
			self.adwordContent = None
			self.advanced = None
			self.skuId = None
			self.beginTime = None
			self.language = None
			self.appLink = None
			self.linkName = None
			self.stopTime = None
			self.productId = None

		def getapiname(self):
			return 'jingdong.com.jd.adword.api.service.AdwordSellerApiService.createAdwordForSku'

			







from jd.api.base import RestApi

class VenderSellerWebControllerOpenVenderAddrVenderAddrFacadeListVenderReturnAddressRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)

		def getapiname(self):
			return 'jingdong.vender.seller.web.controller.open.venderAddr.VenderAddrFacade.listVenderReturnAddress'

			







from jd.api.base import RestApi

class ComJdStockShopGlobalWebOpenWarehouseFacadeAddStoreRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.storeName = None
			self.remark = None
			self.venderId = None
			self.storeId = None

		def getapiname(self):
			return 'jingdong.com.jd.stock.shop.global.web.open.WarehouseFacade.addStore'

			







from jd.api.base import RestApi

class ComEpiCouponOpenApiWriteCreateCouponRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.createCouponWay = None
			self.wareIdList = None
			self.collectionTimeBegin = None
			self.couponType = None
			self.collectionTimeEnd = None
			self.validityType = None
			self.thName = None
			self.usName = None
			self.reonly = None
			self.validityTimeEnd = None
			self.discountOff = None
			self.display = None
			self.discountOffValid = None
			self.takeRule = None
			self.activityLink = None
			self.discount = None
			self.validityTimeBegin = None
			self.num = None
			self.quota = None
			self.discountOffMax = None

		def getapiname(self):
			return 'jingdong.com.epi.couponOpenApiWrite.createCoupon'

			







from jd.api.base import RestApi

class ComJdIntlAsmShopAfsApiServiceQueryAllRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.processResult = None
			self.contactTel = None
			self.auditDateBegin = None
			self.customerPin = None
			self.orderId = None
			self.status = None
			self.pageSize = None
			self.sku = None
			self.auditResult = None
			self.pageIndex = None
			self.serviceId = None
			self.applyTimeBegin = None
			self.applyTimeEnd = None
			self.auditDateEnd = None
			self.language = None
			self.branchId = None

		def getapiname(self):
			return 'jingdong.com.jd.intl.asm.shop.AfsApiService.queryAll'

			







from jd.api.base import RestApi

class ThSellerPopSearchStoreSkuListRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.page = None
			self.pageSize = None
			self.locale = None
			self.skuId = None
			self.categoryId = None
			self.brandId = None
			self.skuName = None
			self.shopCategoryIds = None
			self.status = None
			self.storeIdList = None

		def getapiname(self):
			return 'jingdong.th.seller.pop.searchStoreSkuList'

			







from jd.api.base import RestApi

class ComJdwlSellerAlphaOpenServiceGetDeliveryRecommendCarriersForOpenRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.sendProvinceId = None
			self.locale = None
			self.clientBUId = None
			self.receiveProvinceId = None
			self.receiveTownId = None
			self.sendCountyId = None
			self.area = None
			self.sendTownId = None
			self.sendCityId = None
			self.skus = None
			self.receiveCityId = None
			self.timezoneId = None
			self.orderId = None
			self.receiveCountyId = None

		def getapiname(self):
			return 'jingdong.com.jdwl.seller.AlphaOpenService.getDeliveryRecommendCarriersForOpen'

			







from jd.api.base import RestApi

class ComJdThPopOpenOrderPrintFacadePrintLabelRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.orderIds = None

		def getapiname(self):
			return 'jingdong.com.jd.th.pop.open.OrderPrintFacade.printLabel'

			







from jd.api.base import RestApi

class ComProductUpdateApiServiceUpdateSkusRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.updateSkuApiParam = None

		def getapiname(self):
			return 'jingdong.com.productUpdateApiService.updateSkus'

			
	

class CategoryAttributeValueParam(object):
		def __init__(self):
			"""
			"""
			self.id = None
			self.dimension = None
			self.orderSort = None
			self.comAttId = None
			self.required = None
			self.localeName = None


class SkuApiParam(object):
		def __init__(self):
			"""
			"""
			self.weight = None
			self.stockNum = None
			self.productCode = None
			self.width = None
			self.jdPrice = None
			self.height = None
			self.saleAttrs = None
			self.skuStatus = None
			self.upcCode = None
			self.skuId = None
			self.length = None
			self.outerId = None


class StockParam(object):
		def __init__(self):
			"""
			"""
			self.warehouseId = None
			self.updateStockNum = None


class ImageParam(object):
		def __init__(self):
			"""
			"""
			self.imgUrl = None
			self.index = None
			self.colorId = None


class UpdateSkuApiParam(object):
		def __init__(self):
			"""
			"""
			self.locale = None
			self.skuList = None
			self.updateSkuStockMap = None
			self.imageMap = None
			self.productId = None







from jd.api.base import RestApi

class ComJdGmsGreatdaneCategoryServiceReadCategoryReadServiceGetCategorysRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.categoryIds = None
			self.jarVersion = None
			self.uuid = None
			self.ip = None
			self.hostName = None
			self.instanceHome = None
			self.appId = None
			self.appName = None
			self.sourceIp = None
			self.userAgent = None
			self.businessIdentity = None

		def getapiname(self):
			return 'jingdong.com.jd.gms.greatdane.category.service.read.CategoryReadService.getCategorys'

			







from jd.api.base import RestApi

class ComJdwlApiOrderTrackSiteJsfExportOrderTrackSiteExportAddIntlOrderTrackRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.orderId = None
			self.systemType = None
			self.messageType = None
			self.msgTime = None
			self.locale = None
			self.content = None
			self.title = None
			self.operatorName = None
			self.systemName = None
			self.token = None
			self.locale1 = None
			self.clientBUId = None
			self.timezoneId = None

		def getapiname(self):
			return 'jingdong.com.jdwl.api.order.track.site.jsf.export.OrderTrackSiteExport.addIntlOrderTrack'

			







from jd.api.base import RestApi

class ComEpiPromoOpenApiWriteCreateGiftPromoRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.giftPromoPrice = None
			self.giftSkuId = None
			self.giftQuantity = None
			self.giftProductId = None
			self.giftJdPrice = None
			self.giftSkuName = None
			self.promoPrice = None
			self.skuId = None
			self.quantity = None
			self.productId = None
			self.jdPrice = None
			self.skuName = None
			self.beginTime = None
			self.endTime = None
			self.promoName = None

		def getapiname(self):
			return 'jingdong.com.epi.PromoOpenApiWrite.createGiftPromo'

			







from jd.api.base import RestApi

class ThSellerPopSkuBindStoreRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.batchSkuBindStoreApiParam = None

		def getapiname(self):
			return 'jingdong.th.seller.pop.skuBindStore'

			
	

class Attribute2(object):
		def __init__(self):
			"""
			"""
			self.storeSkuStatus = None
			self.storeId = None


class Attribute1(object):
		def __init__(self):
			"""
			"""
			self.skuId = None
			self.storeApiParamList = None


class BatchSkuBindStoreApiParam(object):
		def __init__(self):
			"""
			"""
			self.batchStoreSkuApiParams = None
			self.locale = None







from jd.api.base import RestApi

class ComJdJinVenderHandlerOpenStatementFacadeListStatementRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.startTime = None
			self.status = None
			self.pageNo = None
			self.pageSize = None
			self.endTime = None
			self.statementId = None

		def getapiname(self):
			return 'jingdong.com.jd.jin.vender.handler.open.StatementFacade.listStatement'

			







from jd.api.base import RestApi

class ComEpiBranchOpenApiWriteBranchCreationRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.branchName = None
			self.provinceId = None
			self.cityId = None
			self.countryId = None
			self.provinceName = None
			self.cityName = None
			self.countryName = None
			self.detailAddress = None
			self.lng = None
			self.lat = None
			self.phoneNumber = None
			self.serviceHotline = None
			self.openedTime = None
			self.closedTime = None
			self.branchLogo = None
			self.attribute = None
			self.advertising = None
			self.pickUpType = None
			self.deliveryRightNowType = None
			self.attribute1 = None
			self.agingType = None
			self.preparedTime = None
			self.subscribeTimeType = None
			self.subscribeTime = None
			self.deliveryRangeType = None
			self.lngAttr = None
			self.latAttr = None
			self.minimumDeliveryPrice = None
			self.weightLimit = None
			self.freeShippingType = None
			self.basicDeliveryPrice = None
			self.distance = None
			self.amount = None
			self.weight = None
			self.weightAmount = None
			self.startTime = None
			self.endTime = None
			self.timeAmount = None
			self.language = None

		def getapiname(self):
			return 'jingdong.com.epi.branchOpenApiWrite.branchCreation'

			







from jd.api.base import RestApi

class ComProductUpdateApiServiceUpdateSpuRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.updateSpuApiParam = None

		def getapiname(self):
			return 'jingdong.com.productUpdateApiService.updateSpu'

			
	

class UpdateSpuApiParam(object):
		def __init__(self):
			"""
			"""
			self.afterSales = None
			self.canUseDQ = None
			self.sn = None
			self.wareQD = None
			self.payFirst = None
			self.locale = None
			self.thName = None
			self.categoryAttrs = None
			self.shopCategory = None
			self.canUseJQ = None
			self.brandId = None
			self.productId = None
			self.templateId = None
			self.shelfLife = None
			self.unit = None
			self.enName = None
			self.promiseId = None
			self.pcDescription = None
			self.is15ToReturn = None
			self.warranty = None
			self.appDescription = None







from jd.api.base import RestApi

class ComJdThPopOpenOrderDeliveryFacadeSplitOrderRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.param = None

		def getapiname(self):
			return 'jingdong.com.jd.th.pop.open.OrderDeliveryFacade.splitOrder'

			
	

class Attribute2(object):
		def __init__(self):
			"""
			"""
			self.id = None
			self.num = None
			self.uuid = None


class Attribute1(object):
		def __init__(self):
			"""
			"""
			self.groupId = None
			self.skus = None


class Param(object):
		def __init__(self):
			"""
			"""
			self.desc = None
			self.venderId = None
			self.skuGroup = None
			self.orderId = None







from jd.api.base import RestApi

class ComJdEtmsWaybillApiGlscGlscWaybillTraceApiGetTraceInfoByOrderRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.countryFlag = None
			self.orderCode = None
			self.locale = None

		def getapiname(self):
			return 'jingdong.com.jd.etms.waybill.api.glsc.GlscWaybillTraceApi.getTraceInfoByOrder'

			







from jd.api.base import RestApi

class ComJdSellerOrderApiCancelFacadeSubmitRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.reasonType = None
			self.reasonCode = None
			self.language = None
			self.orderId = None
			self.reasonDesc = None

		def getapiname(self):
			return 'jingdong.com.jd.seller.order.api.CancelFacade.submit'

			







from jd.api.base import RestApi

class ComEpiCouponOpenApiReadCouponListRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.bindType = None
			self.pageSize = None
			self.couponTitle = None
			self.beginTime = None
			self.language = None
			self.endTime = None
			self.deleteStatus = None
			self.pageNum = None

		def getapiname(self):
			return 'jingdong.com.epi.couponOpenApiRead.couponList'

			







from jd.api.base import RestApi

class ComJdThPopOpenOrderInformationFacadeListOrderRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.sellerSkuId = None
			self.orderCreateTimeBegin = None
			self.pin = None
			self.page = None
			self.paymentType = None
			self.locale = None
			self.skuId = None
			self.pageSize = None
			self.consumerMobilePhone = None
			self.skuName = None
			self.orderStatusType = None
			self.orderId = None
			self.orderCreateTimeEnd = None
			self.open_id_buyer = None

		def getapiname(self):
			return 'jingdong.com.jd.th.pop.open.OrderInformationFacade.listOrder'

			







from jd.api.base import RestApi

class ComJdSellerOrderApiInformationFacadeGetOrderListRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.customerName = None
			self.sellerSkuId = None
			self.phone = None
			self.orderBy = None
			self.orderType = None
			self.paymentType = None
			self.language = None
			self.pageSize = None
			self.pageStart = None
			self.unPrintType = None
			self.endTime = None
			self.period = None
			self.startTime = None
			self.sortType = None
			self.skuId = None
			self.orderId = None
			self.tabStatus = None
			self.modifyTimeBegin = None
			self.modifyTimeEnd = None
			self.deliveryType = None
			self.deliveryStatus = None
			self.storeIds = None

		def getapiname(self):
			return 'jingdong.com.jd.seller.order.api.InformationFacade.getOrderList'

			







from jd.api.base import RestApi

class I18nPlaceOrderServiceJsfGetPreWaybillCodeForOpenApiRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.venderId = None
			self.outSource = None
			self.source = None
			self.orderType = None
			self.customerCode = None
			self.orderId = None
			self.countryFlag = None
			self.siteFlag = None

		def getapiname(self):
			return 'jingdong.i18n.PlaceOrderServiceJsf.getPreWaybillCodeForOpenApi'

			







from jd.api.base import RestApi

class StockUpdateSkuStockRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.sid = None
			self.stockNum = None
			self.skuId = None

		def getapiname(self):
			return 'jingdong.stock.updateSkuStock'

			







from jd.api.base import RestApi

class ComJdSellerOrderApiDeliveryFacadeDeliveryRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.logisticsNo = None
			self.logisticsId = None
			self.logisticsCompany = None
			self.language = None
			self.serviceType = None
			self.addressId = None
			self.orderId = None
			self.deliveryType = None

		def getapiname(self):
			return 'jingdong.com.jd.seller.order.api.DeliveryFacade.delivery'

			







from jd.api.base import RestApi

class ThSellerPopUpdateStoreSkuStockRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.locale = None
			self.skuId = None
			self.storeSkuStockNum = None
			self.storeId = None

		def getapiname(self):
			return 'jingdong.th.seller.pop.updateStoreSkuStock'

			







from jd.api.base import RestApi

class ComEpiPromoOpenApiWriteCreateSuitPromoRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.saveBean = None

		def getapiname(self):
			return 'jingdong.com.epi.PromoOpenApiWrite.createSuitPromo'

			
	

class Attribute2(object):
		def __init__(self):
			"""
			"""
			self.skuId = None
			self.productId = None
			self.promoPrice = None
			self.jdPrice = None
			self.quantity = None
			self.skuName = None


class Attribute1(object):
		def __init__(self):
			"""
			"""
			self.promoSkuBeans = None
			self.discountPrice = None


class SaveBean(object):
		def __init__(self):
			"""
			"""
			self.suitPoolSaveBeans = None
			self.beginTime = None
			self.endTime = None
			self.promoName = None







from jd.api.base import RestApi

class PopAdminExportOrderDeliveryNewRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.logisticsNo = None
			self.logisticsId = None
			self.pickUpAddress = None
			self.logisticsCompany = None
			self.orderId = None

		def getapiname(self):
			return 'jingdong.PopAdminExport.orderDeliveryNew'

			







import pathlib
from setuptools import setup, find_packages

HERE = pathlib.Path(__file__).parent

README = (HERE / "README.md").read_text()

setup(
    name="jd-sdk",
    version="1.1.1",
    packages=find_packages(),
    description="JD Official SDK",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/PsKs/jd-sdk",
    author="Pongsakorn",
    author_email="pongsakorn.psks@gmail.com",
    license="LICENSE.md",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
    ],
    install_requires=["rsa", "psutil", "apscheduler", "wincertstore", "pycryptodome"],
    python_requires='>=3.6',
)



from jd.api.base import RestApi

class ComJdPopVenderCenterI18nApiBusinessBusinessCheckFacadeRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.businessTypes = None
			self.businessUnit = None

		def getapiname(self):
			return 'jingdong.com.jd.pop.vender.center.i18n.api.business.BusinessCheckFacade'

			







from jd.api.base import RestApi

class PopAdminExportQueryListNewRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.phone = None
			self.pin = None
			self.paymentType = None
			self.originStatuList = None
			self.beginTime = None
			self.yn = None
			self.endTime = None
			self.orderStatus = None
			self.orderId = None
			self.pageSize = None
			self.pageStart = None

		def getapiname(self):
			return 'jingdong.PopAdminExport.queryListNew'

			







from jd.api.base import RestApi

class ComJdJinVenderHandlerOpenStatementFacadeStatementDetailRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.settlementId = None
			self.language = None

		def getapiname(self):
			return 'jingdong.com.jd.jin.vender.handler.open.StatementFacade.statementDetail'

			







from jd.api.base import RestApi

class ComEpiBranchOpenApiReadBranchListRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.countryId = None
			self.provinceId = None
			self.cityId = None
			self.branchId = None
			self.branchStatus = None
			self.pageSize = None
			self.branchName = None
			self.pageIndex = None
			self.language = None

		def getapiname(self):
			return 'jingdong.com.epi.BranchOpenApiRead.branchList'

			







from jd.api.base import RestApi

class ComJdSellerTrackApiTrackSynFacadeRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.time = None
			self.trackingNumber = None
			self.status = None
			self.context = None
			self.expressCompany = None

		def getapiname(self):
			return 'jingdong.com.jd.seller.track.api.TrackSynFacade'

			







from jd.api.base import RestApi

class PromotionPriceUpdateSkuPriceJsonWithVenderIdRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.wid = None
			self.salePriceBefore = None
			self.salePrice = None
			self.appReason = None
			self.applicant = None
			self.reviewer = None
			self.auditReason = None

		def getapiname(self):
			return 'jingdong.promotion.price.updateSkuPriceJsonWithVenderId'

			







from jd.api.base import RestApi

class ComEpiPromoOpenApiWriteCreateUnitPromoRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.token = None
			self.perMaxNum = None
			self.promoPrice = None
			self.skuId = None
			self.quantity = None
			self.productId = None
			self.jdPrice = None
			self.skuName = None
			self.beginTime = None
			self.freqBound = None
			self.endTime = None
			self.promoName = None
			self.perMinNum = None

		def getapiname(self):
			return 'jingdong.com.epi.PromoOpenApiWrite.createUnitPromo'

			




